You should pair Tion S3 device with your bluetooth host by two steps:
  1. pressing for 5 second poer button at device 
  2. running ./pair.py device_mac_address while button blinks
before use this module!

If you want to use MagicAir API please follow https://github.com/airens/tion